#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    :
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo


if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi

LIBDIR=lib64
if [ -f $PVSW_ROOT/bin/mkded ]; then
    file -L $PVSW_ROOT/bin/mkded | grep "ELF 32-bit" >/dev/null 2>&1
    if [ $? -eq 0 ] ; then
        LIBDIR=lib
    fi
fi

PATH=$PVSW_ROOT/bin:$PATH
if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    SO_EXTENSION="dylib"
else
    LD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$LD_LIBRARY_PATH
    SO_EXTENSION="so"
fi


echo "+++++ Removing PSQL files..."
####################################################################################
#  Note: Any changes to the files to be removed must be made to the 
#        corresponding PSQL_Linux.spec and PSQL-Linux-Vx.spec files %postun sections. 
####################################################################################
HOMEDIR=`grep "^psql:" /etc/passwd | cut -d: -f6`
rm -f  $HOMEDIR/.cshrc
rm -f  $HOMEDIR/.bash_profile
rm -f  $HOMEDIR/.bash_history
rm -f  $HOMEDIR/.bashrc

rm -f  $PVSW_ROOT/pvinst.log
rm -f  $PVSW_ROOT/LICENSE
rm -f  $PVSW_ROOT/PSQL_Third_Party_Notice
rm -Rf $PVSW_ROOT/bin
rm -Rf $PVSW_ROOT/data/DEMODATA
rm -Rf $PVSW_ROOT/data/TEMPDB
rm -f  $PVSW_ROOT/data/samples/sample.btr
rm -f  $PVSW_ROOT/data/samples/upper.alt
rmdir $PVSW_ROOT/data 2>/dev/null
rmdir $PVSW_ROOT/data/samples 2>/dev/null
rm -Rf $PVSW_ROOT/docs
rm -f  $PVSW_ROOT/etc/confmig.log
rm -f  $PVSW_ROOT/etc/sqlmgr.pid
rm -f  $PVSW_ROOT/etc/preinstall.sh
rm -f  $PVSW_ROOT/etc/postinstall.sh
rm -f  $PVSW_ROOT/etc/postinstall.cfg
rm -f  $PVSW_ROOT/etc/preuninstall.sh
rm -f  $PVSW_ROOT/etc/postuninstall.sh
rm -f  $PVSW_ROOT/etc/psql-unixODBC-2.2.11.tar.gz
rm -Rf $PVSW_ROOT/lib
rm -Rf $PVSW_ROOT/lib64
rm -Rf $PVSW_ROOT/log
rm -Rf $PVSW_ROOT/jre
rm -Rf $PVSW_ROOT/man
rm -Rf $PVSW_ROOT/schemas
echo

if insserv -n > /dev/null 2>&1
then
# In situations where insserv is available, 'preun' is the last point at which
# "insserv -r psql" can be invoked because the main uninstall removes /etc/init.d/psql
# we do that by calling it from preuninstall.sh
    echo ""
else
# So here we just handle cleanup for chkconfig style rc links if they are present.
    echo "+++++ Removing PSQL daemon scripts..."
    if [ -d /etc/rc.d/rc0.d ]; then
        RCDIR=/etc/rc.d
    fi
    if [ -d /etc/rc0.d ]; then
        RCDIR=/etc
    fi
    KILLS=K92psql
    STARTS=S92psql
    rm -f $RCDIR/rc0.d/$KILLS
    rm -f $RCDIR/rc1.d/$KILLS
    rm -f $RCDIR/rc2.d/$STARTS
    rm -f $RCDIR/rc3.d/$STARTS
    rm -f $RCDIR/rc4.d/$STARTS
    rm -f $RCDIR/rc5.d/$STARTS
    rm -f $RCDIR/rc6.d/$KILLS
fi

rm -f /etc/init.d/psql /usr/lib/ocf/resource.d/heartbeat/psql

# remove lock file directory (Debian Linux uses a different lock file directory then the other flavors of Linux)
if [ -d /var/lock/subsys ] ; then
    rm -f /var/lock/subsys/psql
else
    if [ $(uname -s) = "Darwin" ]
    then
        rm -f /var/tmp/psql
    else
        rm -f /var/state/psql
    fi
fi
SERVICES=/etc/services
if [ -f $SERVICES ] ; then
    sed '/PSQL MKDE daemon/d' $SERVICES > /tmp/services
    mv -f /tmp/services $SERVICES
fi
echo


echo "+++++ Removing PSQL PAM settings..."

PAMCONF=/etc/pam.conf
PAMDIR=/etc/pam.d
if [ -f $PAMCONF ] ; then
    FOUND=`grep -c "^pvsw64" $PAMCONF`
    if [ $? -eq 0 ] ; then
	sed '/^pvsw64/d' $PAMCONF > /tmp/pam.conf
	mv -f /tmp/pam.conf $PAMCONF
    fi
fi
rm -f $PAMDIR/pvsw64
rm -f $PAMDIR/pvswauth
rm -f /$LIBDIR/security/pvswauth
rm -f /$LIBDIR/security/pam_pvsw.${SO_EXTENSION}*
if [ $(uname -s) = "Darwin" ]
then
    rm -f /usr/lib/pvswauth
    rm -f /usr/lib/pam_pvsw.${SO_EXTENSION}*
fi
echo

# If this is Darwin.
if [ $(uname -s) = "Darwin" ]
then
    APPLICATIONS="/Applications"

    # If there is an applications directory.
    if [ -d "$APPLICATIONS" ]
    then
        ACTIAN_PSQL_13="$APPLICATIONS/Actian PSQL 13"
        UTILITIES="$ACTIAN_PSQL_13/Utilities"
        SCRIPTS="$ACTIAN_PSQL_13/Scripts"
        echo "+++++ Unpopulating the \"$ACTIAN_PSQL_13\" directory...."
        ERROR=0

        # If removing "PSQL Repair.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Repair.app" || ! rm "$SCRIPTS/.repair"
        then
            ERROR=1
        fi

        # If removing "PSQL Authorize.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Authorize.app" || ! rm "$SCRIPTS/.authorize"
        then
            ERROR=1
        fi

        # If removing "PSQL Licenses.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Licenses.app" || ! rm "$SCRIPTS/.licenses"
        then
            ERROR=1
        fi

        # If removing "PSQL Deauthorize.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Deauthorize.app" || ! rm "$SCRIPTS/.deauthorize"
        then
            ERROR=1
        fi

        # If removing "PSQL Start.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Start.app" || ! rm "$SCRIPTS/.start"
        then
            ERROR=1
        fi

        # If removing "PSQL Status.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Status.app" || ! rm "$SCRIPTS/.status"
        then
            ERROR=1
        fi

        # If removing "PSQL Stop.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Stop.app" || ! rm "$SCRIPTS/.stop"
        then
            ERROR=1
        fi

        # If removing "PSQL Restart.app" fails.
        if ! rm -r "$SCRIPTS/PSQL Restart.app" || ! rm "$SCRIPTS/.restart"
        then
            ERROR=1
        fi

        # If removing "messages" fails.
        if ! rm "$SCRIPTS/.messages"
        then
            ERROR=1
        fi

        # If removing ".DS_Store" fails.
        if ! rm -f "$SCRIPTS/.DS_Store"
        then
            ERROR=1
        fi

        # If removing "$SCRIPTS" fails.
        if ! rmdir "$SCRIPTS"
        then
            ERROR=1
        fi

        # If removing "PSQL Phone Authorization.app" fails.
        if ! rm -r "$UTILITIES/PSQL Phone Authorization.app"
        then
            ERROR=1
        fi

        # If removing "PSQL Notification Viewer.app" fails.
        if ! rm -r "$UTILITIES/PSQL Notification Viewer.app"
        then
            ERROR=1
        fi

        # If removing "PSQL DDF Builder.app" fails.
        if ! rm -r "$UTILITIES/PSQL DDF Builder.app"
        then
            ERROR=1
        fi

        # If removing ".DS_Store" fails.
        if ! rm -f "$UTILITIES/.DS_Store"
        then
            ERROR=1
            fi

        # If removing "$UTILITIES" fails.
        if ! rmdir "$UTILITIES"
        then
            ERROR=1
        fi

        # If removing "PSQL Control Center.app" fails.
        if ! rm -r "$ACTIAN_PSQL_13/PSQL Control Center.app"
        then
            ERROR=1
        fi

        # If removing "PSQL Uninstall.app" fails.
        if ! rm -r "$ACTIAN_PSQL_13/PSQL Uninstall.app" || ! rm "$ACTIAN_PSQL_13/.uninstall"
        then
            ERROR=1
        fi

        # If removing "messages" fails.
        if ! rm "$ACTIAN_PSQL_13/.messages"
        then
            ERROR=1
        fi

        # If removing ".DS_Store" fails.
        if ! rm -f "$ACTIAN_PSQL_13/.DS_Store"
        then
            ERROR=1
        fi

        # If removing "$ACTIAN_PSQL_13" fails.
        if ! rmdir "$ACTIAN_PSQL_13"
        then
            ERROR=1
        fi

        # If there were any errors.
        if [ "$ERROR" -eq 1 ]
        then
            echo "Error: Unable to correctly unpopulate the \"$ACTIAN_PSQL_13\" directory."
            exit 1
        fi

        echo
    fi
fi

echo "Uninstall has successfully completed."
echo



















